@@ -18,8 +18,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_MODELINE_PLUGIN_H__
-#define __GEDIT_MODELINE_PLUGIN_H__
+#ifndef GEDIT_MODELINE_PLUGIN_H
+#define GEDIT_MODELINE_PLUGIN_H
 
 #include <glib.h>
 #include <glib-object.h>
@@ -56,5 +56,5 @@ G_MODULE_EXPORT void peas_register_types (PeasObjectModule *module);
 
 G_END_DECLS
 
-#endif /* __GEDIT_MODELINE_PLUGIN_H__ */
+#endif /* GEDIT_MODELINE_PLUGIN_H */
 /* ex:set ts=8 noet: */
